@@ -11,6 +11,8 @@ using namespace icu;
 void init_char16ptr(py::module &m);
 void init_coleitr(py::module &m);
 void init_idna(py::module &);
+void init_localebuilder(py::module &m);
+void init_localematcher(py::module &m);
 void init_locid(py::module &);
 void init_normalizer2(py::module &m);
 void init_parseerr(py::module &m);
@@ -21,6 +23,7 @@ void init_resbund(py::module &);
 void init_schriter(py::module &);
 void init_sortkey(py::module &);
 void init_strenum(py::module &);
+void init_stsearch(py::module &m);
 void init_tblcoll(py::module &m);
 void init_translit(py::module &m);
 void init_ubidi(py::module &);
@@ -41,6 +44,7 @@ void init_unorm2(py::module &m);
 void init_uregex(py::module &m);
 void init_ures(py::module &m);
 void init_uscript(py::module &m);
+void init_usearch(py::module &m);
 void init_uset(py::module &m);
 void init_ustring(py::module &);
 void init_utext(py::module &);
@@ -83,6 +87,8 @@ PYBIND11_MODULE(MODULE_NAME, m) {
   init_char16ptr(m);
   init_coleitr(m);
   init_idna(m);
+  init_localebuilder(m);
+  init_localematcher(m);
   init_locid(m);
   init_normalizer2(m);
   init_parseerr(m);
@@ -93,6 +99,7 @@ PYBIND11_MODULE(MODULE_NAME, m) {
   init_schriter(m);
   init_sortkey(m);
   init_strenum(m);
+  init_stsearch(m);
   init_tblcoll(m);
   init_translit(m);
   init_ubidi(m);
@@ -113,6 +120,7 @@ PYBIND11_MODULE(MODULE_NAME, m) {
   init_uregex(m);
   init_ures(m);
   init_uscript(m);
+  init_usearch(m);
   init_uset(m);
   init_ustring(m);
   init_utext(m);
