@@ -11,11 +11,14 @@
 #include <unicode/locid.h>
 #include <unicode/uchar.h>
 #include <unicode/uchriter.h>
-#include <unicode/unistr.h>
 
 using namespace icu;
 
 void init_unistr(py::module &m) {
+  // _UnicodeStringVector
+  py::bind_vector<_UnicodeStringVector>(m, "UnicodeStringVector", py::module_local(false))
+      .def(py::init<size_t>(), py::arg("n"));
+
   // Replaceable
   py::class_<Replaceable>(m, "Replaceable")
       .def("char32_at", &Replaceable::char32At, py::arg("offset"))
@@ -53,7 +56,7 @@ void init_unistr(py::module &m) {
            py::arg("codepage"))
       .def(py::init([](const char *src, int32_t src_length, _UConverterPtr &cnv) {
              UErrorCode error_code = U_ZERO_ERROR;
-             auto result = std::unique_ptr<UnicodeString>(new UnicodeString(src, src_length, cnv, error_code));
+             auto result = std::make_unique<UnicodeString>(src, src_length, cnv, error_code);
              if (U_FAILURE(error_code)) {
                throw ICUException(error_code);
              }
@@ -415,7 +418,7 @@ void init_unistr(py::module &m) {
         if (p == 0) {
           return std::nullopt;
         }
-        return std::unique_ptr<_ConstChar16Ptr>(new _ConstChar16Ptr(p));
+        return std::make_unique<_ConstChar16Ptr>(p);
       },
       py::return_value_policy::reference);
   us.def("get_capacity", &UnicodeString::getCapacity);
@@ -428,7 +431,7 @@ void init_unistr(py::module &m) {
         if (p == 0) {
           return std::nullopt;
         }
-        return std::unique_ptr<_ConstChar16Ptr>(new _ConstChar16Ptr(p));
+        return std::make_unique<_ConstChar16Ptr>(p);
       },
       py::return_value_policy::reference);
   us.def("hash_code", &UnicodeString::hashCode);
